@@ -11,7 +11,7 @@ class CoffeeScriptCompiler(SubProcessCompiler):
     def compile_file(self, infile, outfile, outdated=False, force=False):
         if not outdated and not force:
             return  # File doesn't need to be recompiled
-        command = "%s -c %s %s > %s" % (
+        command = "%s -cp %s %s > %s" % (
             settings.PIPELINE_COFFEE_SCRIPT_BINARY,
             settings.PIPELINE_COFFEE_SCRIPT_ARGUMENTS,
             infile,
